# hdpl-conventions/prototype/hdpl/linguam


## ISOs
### ISO 639-3:2007, Codes for the representation of names of languages – Part 3: Alpha-3 code for comprehensive coverage of languages
- https://en.wikipedia.org/wiki/ISO_639-3

#### ConLang Code Registry, by Rebecca Bettencour
- <https://www.kreativekorp.com/clcr/>

### ISO 15924, Codes for the representation of names of scripts
- https://en.wikipedia.org/wiki/ISO_15924
